@@ -1,5 +1,5 @@
 /* Rational - Rational number class with overflow detection
-   Copyright (C) 2012-2020 Antonio Diaz Diaz.
+   Copyright (C) 2012-2022 Antonio Diaz Diaz.
 
    This program is free software. Redistribution and use in source and
    binary forms, with or without modification, are permitted provided
@@ -20,7 +20,7 @@
    Exit status: 0 for a normal exit, 1 for environmental problems
    (file not found, invalid flags, I/O errors, etc), 2 to indicate a
    corrupt or invalid input file, 3 for an internal consistency error
-   (eg, bug) which caused rational to panic.
+   (e.g., bug) which caused rational to panic.
 */
 
 #include <cctype>
@@ -38,7 +38,7 @@
 namespace {
 
 const char * const program_name = "rational";
-const char * const program_year = "2020";
+const char * const program_year = "2022";
 const char * invocation_name = program_name;		// default value
 
 
@@ -51,7 +51,7 @@ void show_help()
                "\nIn case of domain error or overflow, denominator is set to 0 and numerator\n"
                "is set to >0, <0, or 0, meaning +INF, -INF, and NAN respectively. This error\n"
                "condition can be tested with the function 'error', and can only be cleared\n"
-               "assigning a new value to the Rational.\n"
+               "by assigning a new value to the Rational.\n"
                "\nWhile in error state, arithmetic operators become no ops and relational\n"
                "operators return false, except '!=', which returns true. This is done to\n"
                "preserve the error condition which triggered the error, and because the\n"
